"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PasswordField = void 0;
const constants_1 = require("../constants");
const field_1 = require("../field");
class PasswordField extends field_1.Field {
    constructor(parent, form, options) {
        super(parent, form, options);
        this.options = {
            id: '',
            type: constants_1.FIELD_TYPE_PASSWORD,
            required: false,
            validation: (value, data, required) => {
                if (required && !value)
                    return constants_1.DEFAULT_REQUIRED_VALIDATION_MESSAGE;
                return true;
            },
            default: '',
            className: constants_1.INPUT_CLASS_DEFAULT,
            allowPeek: false,
        };
        this.initializeOptions(options);
        this.onGui();
        this.initialize();
        if (this.options.allowPeek) {
            this.addPeekButton();
        }
    }
    addPeekButton() {
        const button = document.createElement(constants_1.BUTTON_ELEMENT);
        const input = this.inputElement;
        const container = document.createElement(constants_1.DIV_ELEMENT);
        container.classList.add(constants_1.FIELD_CONTAINER_PASSWORD_CLASS);
        input.insertAdjacentElement('afterend', container);
        container.append(input, button);
        let isHidden = true;
        hide();
        button.addEventListener(constants_1.CLICK_ATTRIBUTE, (event) => {
            event.preventDefault();
            if (isHidden) {
                show();
            }
            else {
                hide();
            }
        });
        function hide() {
            button.classList.add(constants_1.PASSWORD_HIDDEN_CLASS);
            button.classList.remove(constants_1.PASSWORD_SHOWN_CLASS);
            button.ariaLabel = 'show password';
            input.type = constants_1.FIELD_TYPE_PASSWORD;
            isHidden = true;
        }
        function show() {
            button.classList.add(constants_1.PASSWORD_SHOWN_CLASS);
            button.classList.remove(constants_1.PASSWORD_HIDDEN_CLASS);
            button.ariaLabel = 'hide password';
            input.type = constants_1.FIELD_TYPE_TEXT;
            isHidden = false;
        }
    }
    getValue() {
        return this._value;
    }
}
exports.PasswordField = PasswordField;
