import { Form } from './form';
import { FieldOptions } from './interfaces';
import { FieldValue, HTMLElementEvent } from './types';
import { FieldEvents } from './constants';
export declare class Field {
    options: FieldOptions;
    inputElement: HTMLElement | null;
    containerElement: HTMLElement | null;
    labelElement: HTMLElement | null;
    validationElement: HTMLElement | null;
    hasScheme: boolean;
    private _id;
    private _parent;
    private _form;
    private _isValid;
    private _isDisabled;
    private _isRequired;
    private _isMounted;
    private _isVisible;
    private _saveKey;
    private _vMessage;
    _value: FieldValue;
    private _type;
    private _parsedConditions;
    private _parsedValidationConditions;
    private _parsedRequiredConditions;
    private _parsedDisabledConditions;
    private _triggerEvents;
    constructor(parent: HTMLElement, form: Form, options: FieldOptions);
    initializeOptions(options: FieldOptions): void;
    initialize(): Promise<void>;
    private parseStringConditions;
    setValue(value: FieldValue, save?: boolean): void;
    syncValue(): void;
    getValue(): FieldValue;
    getId(): string;
    getSaveKey(): string;
    getType(): string;
    getVisibility(): boolean;
    getValidity(): boolean | null;
    isDisabled(): boolean;
    isRequired(): boolean;
    getValidationMessage(): string | null;
    getForm(): Form;
    createContainerElement(): void;
    createInputElement(): void;
    createLabelElement(): void;
    createValidationElement(): void;
    onGui(): void;
    private mount;
    private unmount;
    destroy(): void;
    handleValidatedField(): void;
    handleVisibility(): void;
    handleDisabled(): void;
    handleRequired(): void;
    bindChange(): void;
    save(): void;
    load(): void;
    reset(): Promise<void>;
    update(): Promise<void>;
    private updateVisibilityBasedOnConditions;
    private updateDisabledStatus;
    private updateRequiredStatus;
    validate(): boolean | null;
    private setValidationValues;
    change(event: HTMLElementEvent<HTMLInputElement>): void;
    triggerEvents(trigger: boolean): void;
    dispatchEvent(event: FieldEvents, data?: FieldValue): void;
    on(event: string, listener: EventListenerOrEventListenerObject, options: boolean | AddEventListenerOptions): void;
    off(event: string, listener: EventListenerOrEventListenerObject, options: boolean | AddEventListenerOptions): void;
}
